@@ -14,7 +14,7 @@ from kuyruk.worker import Worker
 from kuyruk.events import EventMixin
 from kuyruk.connection import Connection
 
-__version__ = '0.24.0'
+__version__ = '0.24.1'
 __all__ = ['Kuyruk', 'Task', 'Worker']
 
 
@@ -156,10 +156,13 @@ class Kuyruk(EventMixin):
             channel = self.connection().channel()
         except CLOSED:
             logger.warning("Connection is closed. Reconnecting...")
-            try:
-                self._connection.close()
-            except CLOSED:
-                pass
+
+            # If there is a connection, try to close it
+            if self._connection:
+                try:
+                    self._connection.close()
+                except CLOSED:
+                    pass
 
             self._connection = self._connect()
             channel = self._connection.channel()
